@@ -323,7 +323,6 @@ preProcess <- function(targetFile = NULL, url = NULL, archive = NULL, alsoExtrac
   }
 
   # browser(expr = exists("._preProcess_6"))
-
   filesToChecksum <- if (is.null(archive) || isTRUE(is.na(archive))) {
     NULL
   } else {
@@ -874,7 +873,7 @@ preProcess <- function(targetFile = NULL, url = NULL, archive = NULL, alsoExtrac
           filesInHandIP <- checkSumsIPOnlyNeeded$expectedFile
           filesInHandIPLogical <- neededFiles %in% filesInHandIP
           if (any(filesInHandIPLogical)) {
-            outHLC <- hardLinkOrCopy(file.path(dirNameOPFiles, filesInHandIP),
+            outHLC <- hardLinkOrCopy(file.path(dirNameOPFiles[filesInHandIPLogical], filesInHandIP),
                           file.path(destinationPath, filesInHandIP))
             checkSums <- rbindlist(list(checkSumsIPOnlyNeeded, checkSums))
             checkSums <- unique(checkSums, by = "expectedFile")
@@ -1292,11 +1291,13 @@ moveAttributes <- function(source, receiving, attrs = NULL) {
 hardLinkOrCopy <- function(from, to, overwrite = FALSE, verbose = TRUE) {
   outFL <- rep(FALSE, length(from))
 
+  overwriteMess <- ""
   if (length(from)) {
     if (isTRUE(overwrite)) {
       fe <- file.exists(to)
       if (any(fe)) {
         unlinkOut <- unlink(to[fe])
+        overwriteMess <- paste0(to[fe], " exists; overwrite = TRUE; removing first; ")
       }
     }
     # Basically -- all warnings are irrelevant; if fails, it will return FALSE, then it will try the file.copy
@@ -1304,8 +1305,8 @@ hardLinkOrCopy <- function(from, to, overwrite = FALSE, verbose = TRUE) {
     if (any(outFL)) {
       toCollapsed <- paste(to[outFL], collapse = ", ")
       fromCollapsed <- paste(from[outFL], collapse = ", ")
-      messagePrepInputs(hardlinkMessagePrefix, ": ", toCollapsed, ", ",whPointsToMess," "
-                        , fromCollapsed, "; no copy/copies made.", verbose = verbose)
+      messagePrepInputs(overwriteMess, hardlinkMessagePrefix, ": ", toCollapsed, ", ",whPointsToMess," "
+                        , fromCollapsed, "; no copy/copies made.", verbose = verbose, collapse = "\n")
     }
     if (any(!outFL)) {
       outFL <- copyFile(to = to[!outFL], from = from[!outFL], overwrite = overwrite, silent = TRUE)
