@@ -123,9 +123,36 @@ setMethod(
       return(out)
     }
 
+    if (inherits(object, "SpatRaster")) {
+      if (!requireNamespace("terra") && getOption("reproducible.useTerra", FALSE))
+        stop("Please install terra package")
+      if (any(nchar(terra::sources(object)) > 0)) {
+        out <- lapply(terra::sources(object), function(x)
+          digest(file = x, length = length, algo = algo))
+        dig <- .robustDigest(append(
+          list(terra::nrow(object), terra::ncol(object), terra::nlyr(object),
+               terra::res(object), terra::crs(object),
+               terra::ext(object)), object@ptr$names, ),
+          length = length, quick = quick,
+          algo = algo, classOptions = classOptions) # don't include object@data -- these are volatile
+        out <- .doDigest(list(out, dig), algo = algo)
+      } else {
+        out <- .doDigest(terra::wrap(object), algo)
+      }
+
+      return(out)
+    }
+
+    if (any(inherits(object, "SpatVector"), inherits(object, "SpatRaster"))) {
+      if (!requireNamespace("terra") && getOption("reproducible.useTerra", FALSE))
+        stop("Please install terra package")
+      out <- .doDigest(terra::wrap(object), algo)
+      return(out)
+    }
+
     # passByReference -- while doing pass by reference attribute setting is faster, is
     #   may be wrong. This caused issue #115 -- now fixed because it doesn't do pass by reference
-    object1 <- .removeCacheAtts(object, passByReference = FALSE)
+    object1 <- .removeCacheAtts(object)
     .doDigest(object1, algo)
 })
 
@@ -147,6 +174,15 @@ setMethod(
     .robustDigestFormatOnly(object, algo = algo)
 })
 
+#' @rdname robustDigest
+#' @export
+setMethod(
+  ".robustDigest",
+  signature = "language",
+  definition = function(object, .objects, length, algo, quick, classOptions) {
+    .robustDigestFormatOnly(object, algo = algo)
+  })
+
 #' @rdname robustDigest
 #' @export
 setMethod(
@@ -155,26 +191,30 @@ setMethod(
   definition = function(object, .objects, length, algo, quick, classOptions) {
     object <- .removeCacheAtts(object)
 
+    simpleDigest <- TRUE
     if (!quick) {
-        if (any(unlist(lapply(object, file.exists)))) {
-          # browser(expr = exists("hhhh"))
-          unlist(lapply(object, function(x) {
-            # browser(expr = exists("hhhh"))
-            if (dir.exists(x)) {
-              .doDigest(basename(x), algo)
-            } else if (file.exists(x)) {
-                digest(file = x, length = length, algo = algo)
-            } else {
-              .doDigest(x, algo)
-            }
-          }))
+      if (any(unlist(lapply(object, file.exists)))) {
+        simpleDigest <- FALSE
+      }}
+    if (!simpleDigest) {
+      # browser(expr = exists("hhhh"))
+      unlist(lapply(object, function(x) {
+        # browser(expr = exists("hhhh"))
+        if (dir.exists(x)) {
+          .doDigest(basename(x), algo)
+        } else if (file.exists(x)) {
+          digest(file = x, length = length, algo = algo)
         } else {
-          .doDigest(object, algo = algo)
+          .doDigest(x, algo)
         }
-      } else {
-        .doDigest(object, algo = algo)
-      }
-})
+      }))
+      #} else {
+      #.doDigest(object, algo = algo)
+      #}
+    } else {
+      .doDigest(object, algo = algo)
+    }
+  })
 
 #' @rdname robustDigest
 #' @export
@@ -212,10 +252,27 @@ setMethod(
   signature = "environment",
   definition = function(object, .objects, length, algo, quick, classOptions) {
     object <- .removeCacheAtts(object)
-    .robustDigest(as.list(object, all.names = TRUE), .objects = .objects,
-                 length = length,
-                 algo = algo, quick = quick)
-})
+    if (is.null(classOptions[["prevEnvir"]])) {
+      classOptions[["prevEnvir"]] <- list()
+      doneAlready <- list(FALSE)
+    } else {
+      doneAlready <- lapply(classOptions[["prevEnvir"]], function(pe) identical(pe, object))
+    }
+    classOptions[["prevEnvir"]] <- unique(append(classOptions[["prevEnvir"]], object))
+
+    if (!any(unlist(doneAlready))) {
+      asList <- as.list(object, all.names = TRUE)
+      da <- which(unlist(doneAlready))
+      if (length(da))
+        asList <- asList[-da]
+      rd <- .robustDigest(asList, .objects = .objects,
+                          length = length,
+                          algo = algo, quick = quick, classOptions = classOptions)
+    } else {
+      rd <- NULL
+    }
+    return(rd)
+  })
 
 #' @rdname robustDigest
 #' @export
@@ -228,10 +285,10 @@ setMethod(
     if (!is.null(.objects)) object <- object[.objects]
     lapply(.sortDotsUnderscoreFirst(object), function(x) {
       .robustDigest(object = x, .objects = .objects,
-                   length = length,
-                   algo = algo, quick = quick)
+                    length = length,
+                    algo = algo, quick = quick, classOptions = classOptions)
     })
-})
+  })
 
 #' @rdname robustDigest
 #' @export
@@ -241,9 +298,48 @@ setMethod(
   definition = function(object, .objects, length, algo, quick, classOptions) {
     #  Need a specific method for data.frame or else it get "list" method, which is wrong
     object <- .removeCacheAtts(object)
-    .doDigest(object, algo = algo)
+    dig <- lapply(object, .robustDigest, algo = algo, classOptions = classOptions)
+    .robustDigest(unlist(dig), quick = TRUE, algo = algo, classOptions = classOptions)
 })
 
+
+#' @rdname robustDigest
+#' @export
+setMethod(
+  ".robustDigest",
+  signature = "numeric",
+  definition = function(object, .objects, length, algo, quick, classOptions) {
+    #  Need a specific method for data.frame or else it get "list" method, which is wrong
+    object <- .removeCacheAtts(object)
+    # From ad hoc tests, 6 was the highest I could go to maintain consistent between Linux and Windows
+    .doDigest(round(object, getOption("reproducible.digestDigits", 7)), algo = algo)
+  })
+
+#' @rdname robustDigest
+#' @export
+setMethod(
+  ".robustDigest",
+  signature = "matrix",
+  definition = function(object, .objects, length, algo, quick, classOptions) {
+    #  Need a specific method for data.frame or else it get "list" method, which is wrong
+    object <- .removeCacheAtts(object)
+    dim(object) <- NULL
+    .robustDigest(object, classOptions = classOptions)
+    # From ad hoc tests, 6 was the highest I could go to maintain consistent between Linux and Windows
+  })
+
+#' @rdname robustDigest
+#' @export
+setMethod(
+  ".robustDigest",
+  signature = "integer",
+  definition = function(object, .objects, length, algo, quick, classOptions) {
+    #  Need a specific method for data.frame or else it get "list" method, which is wrong
+    object <- .removeCacheAtts(object)
+    # From ad hoc tests, 7 was the highest I could go to maintain consistent between Linux and Windows
+    .doDigest(object, algo = algo)
+  })
+
 #' @rdname robustDigest
 #' @export
 setMethod(
@@ -273,13 +369,14 @@ setMethod(
     return(dig)
 })
 
+
 #' @rdname robustDigest
 #' @export
 setMethod(
   ".robustDigest",
   signature = "Spatial",
   definition = function(object, .objects, length, algo, quick, classOptions) {
-    object <- .removeCacheAtts(object)
+    object <- .removeCacheAtts(object, passByReference = FALSE)
 
   if (is(object, "SpatialPoints")) {
       aaa <- as.data.frame(object)
@@ -329,7 +426,7 @@ setMethod(
 #' @param passByReference Logical. If \code{TRUE}, the default, this uses \code{data.table::setattr}
 #'   to remove several attributes that are unnecessary for digesting, specifically \code{tags},
 #'   \code{.Cache} and \code{call}
-.removeCacheAtts <- function(x, passByReference = TRUE) {
+.removeCacheAtts <- function(x, passByReference = FALSE) {
   if (passByReference) {
     setattr(x, "tags", NULL)
     setattr(x, ".Cache", NULL)
