@@ -2,9 +2,6 @@
   Require::checkPath(.reproducibleTempCacheDir(), create = TRUE)
   Require::checkPath(.reproducibleTempInputDir(), create = TRUE)
 
-  if (requireNamespace("rgdal", quietly = TRUE))
-    rgdal::set_thin_PROJ6_warnings(TRUE)
-  suppressWarnings(raster::crs("+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"))
   ## set options using the approach used by devtools
   opts <- options()
   opts.reproducible <- reproducibleOptions()
